@@ -1,4 +1,7 @@
 from typing import Optional
+
+import torch
+
 from classy_imaginary import config
 from classy_imaginary.api import _generate_single_image
 from classy_imaginary import ImaginePrompt, ImagineResult
@@ -6,9 +9,9 @@ from classy_imaginary.enhancers.face_restoration_codeformer import codeformer_mo
 from classy_imaginary.model_manager import get_diffusion_model
 from classy_imaginary.modules.midas.utils import AddMiDaS
 from classy_imaginary.safety import EnhancedStableDiffusionSafetyChecker
-
-import logging
+from classy_imaginary.utils import platform_appropriate_autocast, fix_torch_nn_layer_norm, fix_torch_group_norm
 from transformers import logging as transformers_logging, AutoFeatureExtractor
+import logging
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
@@ -72,21 +75,23 @@ class Imagine:
         :param progress_img_interval_min_s: the minimum time between progress images.
         :return: a list of ImagineResult objects.
         """
+        with torch.no_grad(), platform_appropriate_autocast(
+                self.precision,
+        ), fix_torch_nn_layer_norm(), fix_torch_group_norm():
+            result = _generate_single_image(
+                prompt,
+                self.sd_model,
+                midas_model=self.midas_model,
+                nsfw_filter=nsfw_filter,
+                safety_feature_extractor=self.safety_feature_extractor,
+                safety_checker=self.safety_checker,
+                codformer_model=self.code_former_model,
+                debug_img_callback=debug_img_callback,
+                progress_img_callback=progress_img_callback,
+                progress_img_interval_steps=progress_img_interval_steps,
+                progress_img_interval_min_s=progress_img_interval_min_s,
+                half_mode=self.half_mode,
+                add_caption=False,
+            )
 
-        result = _generate_single_image(
-            prompt,
-            self.sd_model,
-            midas_model=self.midas_model,
-            nsfw_filter=nsfw_filter,
-            safety_feature_extractor=self.safety_feature_extractor,
-            safety_checker=self.safety_checker,
-            codformer_model=self.code_former_model,
-            debug_img_callback=debug_img_callback,
-            progress_img_callback=progress_img_callback,
-            progress_img_interval_steps=progress_img_interval_steps,
-            progress_img_interval_min_s=progress_img_interval_min_s,
-            half_mode=self.half_mode,
-            add_caption=False,
-        )
-
-        return result
+            return result
