@@ -5,16 +5,19 @@ DEFAULT_MODEL = "SD-1.5"
 DEFAULT_SAMPLER = "k_dpmpp_2m"
 
 DEFAULT_NEGATIVE_PROMPT = (
-    "(weird eyes:1.5), smudged face, (blurred face:1.5), (poorly drawn face:1.5), mutation, mutilation, cloned face, (strange mouth:1.5), (duplicated face:2.0), "
+    "(weird eyes:1.5), (smudged face:1.8), (blurred face:1.5), (poorly drawn face:1.5), mutation, mutilation, (cloned face:2.0), (strange mouth:1.5), (duplicated face:2.0), "
     "(Ugly:1.5), (duplication:1.5), duplicates, mutilation, deformed, mutilated, (mutation:1.5), (twisted body:1.5), (disfigured:1.5), (bad anatomy:1.5), "
     "(poorly drawn hands:1.5), (extra limbs:1.5), (malformed limbs:1.5), (missing arms:1.5), (extra arms:1.5), (missing legs:1.5), (extra legs:1.5), (mutated hands:1.5), "
-    "(extra hands:1.5), (fused fingers:1.5), (missing fingers:1.5), extra fingers, long neck, small head, closed eyes, rolling eyes, "
-    "grainy, blurred, blurry, writing, calligraphy, (text:3.0), (watermark:1.5), bad art, "
+    "(extra hands:1.5), (fused fingers:1.5), (missing fingers:1.5), extra fingers, (long neck:1.8), small head, (closed eyes:1.5), rolling eyes, "
+    "grainy, blurred, blurry, (writing:1.5), calligraphy, (text:3.0), (watermark:1.5), bad art, missing fingers, (missing limbs:1.5), "
     "(out of frame:1.5), (extra fingers:1.5), (mutated hands:1.5), (porn:1.5), (child abuse:1.5), (horrific images:1.5), (dead bodies:1.5), "
-    "(watermark:1.5), child, lowres, bad anatomy, bad hands, text, error, (missing fingers:1.5), extra digit, fewer digits, cropped, "
-    "worst quality, (low quality:1.5), normal quality, jpeg artifacts, (signature:1.5), watermark, username, blurry, (bad feet:1.5), bad lighting, "
-    "bad coloring, bad perspective, (bad focus:1.5), bad design, bad eyes, bad hair, bad nose, bad mouth, bad ears, bad teeth, bad tongue, bad lips, "
-    "(nude:1.5), (naked:1.5), (paedophile:2.0), (pedo:2.0)"
+    "(watermark:1.5), child, (lowres:1.5), bad anatomy, bad hands, text, error, (missing fingers:1.5), (extra digit:1.5), (fewer digits:1.6), (cropped:1.5), "
+    "worst quality, (low quality:1.5), normal quality, jpeg artifacts, (signature:1.5), watermark, username, blurry, (bad feet:1.5), (bad lighting:1.3), "
+    "bad coloring, bad perspective, (bad focus:1.5), (bad design:1.3), (bad eyes:1.7), (bad hair:1.7), bad nose, bad mouth, bad ears, bad teeth, bad tongue, bad lips, "
+    "(nude:1.5), (naked:1.5), (paedophile:2.0), (pedo:2.0), (floating limbs: 1.5), (bad art, low detail:1.5), (plain background, grainy, low "
+    "quality, mutated hands and fingers:1.4), (watermark, thin lines:1.2), (deformed, signature:1.2), (blurry, ugly, bad anatomy, extra"
+    "limbs, undersaturated, low resolution:1.5), (disfigured, deformations, out of frame:1.5), (amputee:1.8), (bad proportions:1.5), (extra limb:1.5), (missing"
+    "limbs:1.4), (distortion:1.5), (out of frame:2.0), (poorly drawn face:2.0), (poorly drawn hands:1.5), (text:1.8), malformed, (cropped:1.5)"
 )
 
 SPLITMEM_ENABLED = False
@@ -204,7 +207,14 @@ MODEL_CONFIGS = [
         config_path="configs/stable-diffusion-v1.yaml",
         weights_url="https://huggingface.co/dreamlike-art/dreamlike-photoreal-2.0/resolve/main/dreamlike-photoreal-2.0.ckpt",
         default_image_size=512,
-        alias="swp"
+        alias="dlh"
+    ),
+    ModelConfig(
+        short_name="DreamLikeDiffusion",
+        config_path="configs/stable-diffusion-v1.yaml",
+        weights_url="https://huggingface.co/dreamlike-art/dreamlike-diffusion-1.0/resolve/main/dreamlike-diffusion-1.0.ckpt",
+        default_image_size=640,
+        alias="dld"
     ),
     # ModelConfig(
     #     short_name="SD-2.0-upscale",
